aboutsummaryrefslogtreecommitdiffstats
path: root/OpenAL32
diff options
context:
space:
mode:
authorChris Robinson <[email protected]>2016-04-15 18:14:19 -0700
committerChris Robinson <[email protected]>2016-04-15 18:14:19 -0700
commite16032e1f0c92ff23c70393eccbac7def14d4bab (patch)
treede25640c8e3acd3d2ba35d50e1c32099d2c7e311 /OpenAL32
parentbd65f64d0506be6f20d69311c9a6ade3d0a8d01d (diff)
Update some comments
Diffstat (limited to 'OpenAL32')
-rw-r--r--OpenAL32/Include/alu.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/OpenAL32/Include/alu.h b/OpenAL32/Include/alu.h
index 8a0aa81e..8b11bdd4 100644
--- a/OpenAL32/Include/alu.h
+++ b/OpenAL32/Include/alu.h
@@ -300,7 +300,7 @@ void aluInitEffectPanning(struct ALeffectslot *slot);
* CalcDirectionCoeffs
*
* Calculates ambisonic coefficients based on a direction vector. The vector
- * must not be longer than 1 unit.
+ * must be normalized (unit length).
*/
void CalcDirectionCoeffs(const ALfloat dir[3], ALfloat coeffs[MAX_AMBI_COEFFS]);
@@ -319,10 +319,11 @@ inline void CalcXYZCoeffs(ALfloat x, ALfloat y, ALfloat z, ALfloat coeffs[MAX_AM
/**
* CalcAngleCoeffs
*
* Calculates ambisonic coefficients based on angle and elevation. The angle
* and elevation parameters are in radians, going right and up respectively.
*/
-void CalcAngleCoeffs(ALfloat angle, ALfloat elevation, ALfloat coeffs[MAX_AMBI_COEFFS]);
+void CalcAngleCoeffs(ALfloat azimuth, ALfloat elevation, ALfloat coeffs[MAX_AMBI_COEFFS]);
/**
* ComputeAmbientGains
@@ -319,10 +319,11 @@ inline void CalcXYZCoeffs(ALfloat x, ALfloat y, ALfloat z, ALfloat coeffs[MAX_AM
* CalcAngleCoeffs
*
- * Calculates ambisonic coefficients based on angle and elevation. The angle
- * and elevation parameters are in radians, going right and up respectively.
+ * Calculates ambisonic coefficients based on azimuth and elevation. The
+ * azimuth and elevation parameters are in radians, going right and up
+ * respectively.
*/